@@ -45,6 +45,15 @@ for(myKernel in KERNELS) {
 
 
 
+d <-2 * matrix(c(9,  8,  5,  7,  7,  2
+     ,  8,  9,  2,  5,  1,  7
+     ,  5,  2,  9,  8,  7,  1
+     ,  7,  5,  8,  9,  3,  2
+     ,  7,  1,  7,  3,  9,  6
+     ,  2,  7,  1,  2,  6,  9),ncol=6,byrow=TRUE) - 9
+
+pop(d)
+
 
 
 
